@ECHO OFF

:: Force working directory to be current directory
PUSHD %~dp0

:: Check for the existence of AgentSetup.exe in Component flag message if missing
IF NOT EXIST AgentSetup.exe GOTO filemissing

:: Output input variables to StdOut to summarise your input
ECHO.Using the following Input Variables:
ECHO.mapped_drive_letter: %mapped_drive_letter%
ECHO.mapped_drive_folder: %mapped_drive_folder%
ECHO.install_folder_name: %install_folder_name%
ECHO.

:: Map temporary network drive using supplied input variables
ECHO.Mapping temporary drive to %mapped_drive_letter% using the following path: \\%computername%\%mapped_drive_folder%
NET USE %mapped_drive_letter% \\%computername%\%mapped_drive_folder%
ECHO.

:: Check for existence of install folder and create if not present
ECHO.Creating installation folder if not already present
SET install_folder=%mapped_drive_letter%\%install_folder_name%
IF NOT EXIST %install_folder% MD %install_folder%
ECHO.

:: Create agent installation command variable
SET install_command=AgentSetup.exe
IF DEFINED cs_profile_uid SET install_command=%install_command% /PROF %cs_profile_uid%
IF DEFINED cs_profile_proxy_type SET install_command=%install_command% /PXTP %cs_profile_proxy_type%
IF DEFINED cs_profile_proxy_port SET install_command=%install_command% /PXPT %cs_profile_proxy_port%
IF DEFINED cs_profile_proxy_host SET install_command=%install_command% /PXAD %cs_profile_proxy_host%
IF DEFINED cs_profile_proxy_username SET install_command=%install_command% /PXUS %cs_profile_proxy_username%
IF DEFINED cs_profile_proxy_password SET install_command=%install_command% /PXPD %cs_profile_proxy_password%

:: Add agent installation line to Agent_Deploy.bat
ECHO.%install_command% >> Agent_Deploy.bat

:: Copy required files to installation folder
ECHO.Copying required files to installation folder
COPY AgentSetup.exe %install_folder% /Y
COPY Agent_Deploy.bat %install_folder% /Y

:: Output contents of installation folder for validation
ECHO.Checking contents of installation folder:
DIR %install_folder%
ECHO.

:: Output contents of startup script file for validation
ECHO.Agent_Deploy.bat has been created with the following contents:
ECHO.
TYPE %install_folder%\Agent_Deploy.bat
ECHO.
ECHO.
ECHO.

:cleanup
:: Remove temporary mapped drive
ECHO.Removing temporary mapped drive %mapped_drive_letter%
NET USE /DELETE %mapped_drive_letter%

:creategpo
:: Check if GPO is already created and exit if so, otherwise create it and set a flag
reg query HKLM\SOFTWARE\CentraStage /v GPOCreated
if %ERRORLEVEL% EQU 0 exit 0
echo.Creating startup script GPO with link to root of domain
echo.
CreateGPO.exe
echo.
reg add HKLM\Software\CentraStage /v GPOCreated /t REG_DWORD /d 1 /f
exit 0

:filemissing
ECHO.AgentSetup.exe not found. Please ensure that AgentSetup.exe has been added to the Component
ECHO.
exit 1